`#system#`你是一个确定从上下文信息中提取的实体是否是已有实体的重复项的可靠助手。
`#user#`# 上下文信息

{{context}}

<已有实体>
{{entities}}
</已有实体>

<候选实体>
{{candidate_entities}}
</候选实体>

# 你的任务
请检查上述每个候选实体，确定该实体是否为任何已有实体的重复项。若已有实体中也有重复项，请一并处理。

## 注意事项
只有当实体指向*现实世界的同一事物或概念*时，才将其视为重复项。
候选实体均为当前上下文中提到的，他们有可能为同名已有实体的重复项，尤其是代表AI助手或人类用户/对话参与者的实体。

以下情况不要将实体标记为重复项：
- 它们相关但不同。
- 它们有相似的名称或属性，但指向不同的事物或概念。{{extra_message}}